@@ -2,23 +2,25 @@
 -----BEGIN PGP SIGNED MESSAGE-----
 Hash: SHA1
 
+=encoding utf8
+
 =head1 NAME
 
 Time::Format - Easy-to-use date/time formatting.
 
 =head1 VERSION
 
-This documentation describes version 1.10 of Time::Format.pm, June 17, 2009.
+This is version 1.13 of Time::Format, July 18, 2019.
 
 =cut
 
 use strict;
 package Time::Format;
-$Time::Format::VERSION  = '1.10';
+$Time::Format::VERSION  = '1.13';
 
 # This module claims to be compatible with the following versions
 # of Time::Format_XS.
-%Time::Format::XSCOMPAT = map {$_ => 1} qw(1.01 1.02);
+%Time::Format::XSCOMPAT = map {$_ => 1} qw(1.01 1.02 1.03);
 
 sub _croak
 {
@@ -262,7 +264,7 @@ sub setup_locale
 
     my (@Month, @Mon, @Weekday, @Day);
 
-    eval {
+    unless (eval {
         require I18N::Langinfo;
         I18N::Langinfo->import(qw(langinfo));
         @Month = map langinfo($_),   I18N::Langinfo::MON_1(),    I18N::Langinfo::MON_2(),    I18N::Langinfo::MON_3(),
@@ -277,9 +279,10 @@ sub setup_locale
             I18N::Langinfo::DAY_4(), I18N::Langinfo::DAY_5(),    I18N::Langinfo::DAY_6(),    I18N::Langinfo::DAY_7();
         @Day     = map langinfo($_), I18N::Langinfo::ABDAY_1(),  I18N::Langinfo::ABDAY_2(),  I18N::Langinfo::ABDAY_3(),
           I18N::Langinfo::ABDAY_4(), I18N::Langinfo::ABDAY_5(),  I18N::Langinfo::ABDAY_6(),  I18N::Langinfo::ABDAY_7();
-    };
-    if ($@)    # Internationalization didn't work for some reason; go with English.
-    {
+        1;
+        }
+           )
+    {    # Internationalization didn't work for some reason; go with English.
         @Month   = @{ $english_names{Month} };
         @Weekday = @{ $english_names{Weekday} };
         @Mon     = map substr($_,0,3), @Month;
@@ -336,22 +339,27 @@ sub _classify_time
     # Stringified DateTime object
     # Except we make it more flexible by allowing the date OR the time to be specfied
     # This will also match Date::Manip strings, and many ISO-8601 strings.
-    elsif ($timeval =~ m{\A(   (?!>\d{6,8}\z)                # string must not consist of only 6 or 8 digits.
-                          (?:
-                            \d{4} [-/.]? \d{2} [-/.]? \d{2}  # year-month-day
+    elsif ($timeval =~ m{\A(   (?!\d{6,8}\z)                 # string must not consist of only 6 or 8 digits.
+                          (?:                                # year-month-day
+                                   \d{4}                     #     year
+                            [-/.]? (?:0[1-9]|1[0-2])         #     month
+                            [-/.]? (?:0[1-9]|[12]\d|3[01])   #     day
                           )?                                 # ymd is optional
                           (?:  (?<=\d)  [T_ ]  (?=\d) )?     # separator: T or _ or space, but only if ymd and hms both present
                         )                                    # End of $1: YMD and separator
                           (?:                                # hms is optional
                         (
-                            \d{2} [:.]? \d{2} [:.]? \d{2}    # hour:minute:second
+                                  (?:[01]\d|2[0-4])          #     hour
+                            [:.]? (?:[0-5]\d)                #     minute
+                            [:.]? (?:[0-5]\d|6[0-1])?        #     second
                         )                                    # End of $2: HMS
                             (?: [,.] (\d+))?                 # optional fraction
+                            (Z?)                             # optional "zulu" (UTC) designator
                           )?                                 # end of optional (HMS.fraction)
                         \z
                       }x)
     {
-        $cache_value = ($1 || q{}) . ($2 || q{});
+        $cache_value = ($1 || q{}) . ($2 || q{}) . ($4 || q{});
         $frac        = $3? '0.' . $3 : 0;
         $time_type   = $DATETIME_STRING;
     }
@@ -369,7 +377,7 @@ sub _classify_time
         # Get numeric time
         $timeval     = _have('Time::HiRes')? Time::HiRes::time() : time;
         $cache_value = int $timeval;
-        $frac        = $cache_value - $timeval;
+        $frac        = $timeval - $cache_value;
         $time_type   = $NUMERIC_TIME;
     }
     else
@@ -451,7 +459,7 @@ sub decode_DateTime_object
              $dt->second,  $dt->minute, $dt->hour,
              $dt->day,     $dt->month,  $dt->year,
              $dt->dow,     $dt->doy,    $dt->is_dst);
-    $t[-1] = 0 if $t[-1] == 7;   # Convert 1-7 (Mon-Sun) to 0-6 (Sun-Sat).
+    $t[-3] = 0 if $t[-3] == 7;   # Convert 1-7 (Mon-Sun) to 0-6 (Sun-Sat).
 
     return @t;
 }
@@ -468,6 +476,7 @@ sub decode_DateTime_string
                       (?:                                      # hms is optional
                          (\d{2}) [:.]? (\d{2}) [:.]? (\d{2})   # hour:minute:second
                          (?: [,.] \d+)?                        # optional fraction (ignored in this sub)
+                         (Z?)                                  # optional "zulu" (UTC) indicator
                       )?   \z
                      }x)
     {
@@ -476,9 +485,9 @@ sub decode_DateTime_string
         die qq{Unrecognized DateTime string "$dts": probable Time::Format bug};
     }
 
-    my ($y,$mon,$d,$h,$min,$s) = ($1,$2,$3,$4,$5,$6);
+    my ($y,$mon,$d,$h,$min,$s,$tz) = ($1,$2,$3,$4,$5,$6,$7);
     my ($d_only, $t_only);
-    my ($h12, $tz, $is_dst, $dow);
+    my ($h12, $is_dst, $dow);
     if (!defined $y)
     {
         # Time only.  Set date to 1969-12-31.
@@ -519,8 +528,14 @@ sub decode_DateTime_string
     my @t = map {$_+0} ($s,$min,$h,$d,$mon,$y);
     $h12 += 0;
 
-    $tz = POSIX::strftime('%Z', @t, $dow, -1, $is_dst)
-        if _have('POSIX');
+    if ($tz  &&  $tz eq 'Z')
+    {
+        $tz = 'UTC';
+    }
+    elsif (_have('POSIX'))
+    {
+        $tz = POSIX::strftime('%Z', @t, $dow, -1, $is_dst);
+    }
 
     return ($h12, $tz, @t, $dow, -1, $is_dst);
 }
@@ -542,7 +557,7 @@ sub decode_epoch
 #  $int = dow ($year, $month, $day);
 #
 # Returns the day of the week (0=Sunday .. 6=Saturday).  Uses Zeller's
-# congruence, so it is't subject to the unix 2038 limitation.
+# congruence, so it isn't subject to the unix 2038 limitation.
 #
 #--->     $int = dow ($year, $month, $day);
 sub _dow
@@ -565,7 +580,7 @@ sub _dow
 # The heart of the module.  Didja ever see so many wicked regexes in a row?
 
 my %disam;    # Disambiguator for 'm' format.
-$disam{$_} = "{on}" foreach qw/yy d dd ?d/;           # If year or day is nearby, it's 'month'
+$disam{$_} = "{on}" foreach qw/yy d dd ?d/;                # If year or day is nearby, it's 'month'
 $disam{$_} = "{in}" foreach qw/h hh ?h H HH ?H s ss ?s/;   # If hour or second is nearby, it's 'minute'
 sub time_format_perlonly
 {
@@ -1126,7 +1141,7 @@ limitation.
 
 =head1 AUTHOR / COPYRIGHT
 
-Copyright (c) 2003-2009 by Eric J. Roode, ROODE I<-at-> cpan I<-dot-> org
+Copyright (c) 2003-2019 by Eric J. Roode, ROODE I<-at-> cpan I<-dot-> org
 
 All rights reserved.
 
@@ -1154,11 +1169,10 @@ endeavor to improve the software.
 =begin gpg
 
 -----BEGIN PGP SIGNATURE-----
-Version: GnuPG v1.4.9 (Cygwin)
 
-iEYEARECAAYFAko5NuoACgkQwoSYc5qQVqrFsgCfcAswyqznrx5Dam0ejkSo6S8M
-DnMAoI/AIqkl970qS7PYBw4zh+eu8bsx
-=L+eA
+iF0EARECAB0WIQTSmjxiQX/QfjsCVJLChJhzmpBWqgUCXTDGigAKCRDChJhzmpBW
+qh3uAKCCMrRX1Au01PU8UkdqA82bnKj7MgCgrjVQPbJYHYGmwyUeXAicd91uvYQ=
+=o00S
 -----END PGP SIGNATURE-----
 
 =end gpg
